# 🐜: `abbrev`: Expand abbreviations 🐜

::: abbrev

## About this project

* [ Source code ]( https://github.com/rec/abbrev )
* [ More by this author ]( https://github.com/rec )
* [ Sponsors ]( https://github.com/sponsors/rec )
